==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Добрый день @nom@ !',
	'c_accueil_configurer_site' => 'Настроить сайт',
	'c_accueil_configurer_site_texte' => 'Первое, что вы можете сделать - это изменить название вашего сайта.
Сейчас он называется «@nom@». Название  показывается в правом верхнем углу страницы. Нажав на имя сайта вы можете изменить его.',
	'c_accueil_publication' => 'Опубликовать!',
	'c_accueil_publication_texte' => 'Чтобы сделать новую страницу сайта вам необходимо создать новую статью. Также необходимо, чтобы у вас была минимум одна рубрика сайта. Если на сайте нет ни одной рубрики, вы можете создать её, нажав на пункт меню «Сайт -> Рубрики» в верхней панели управления.',
	'c_accueil_texte' => 'Вы только что вошли в систему управления вашим сайтом - CMS SPIP.',
	'c_accueil_texte_revenir' => '		На этой странице отображаются последние изменения, которые были выполненный на сайте. В дальнейшем вы можете вернуться на эту страницу, нажав на кнопку «Главная» в левом верхнем углу страницы.',
	'c_article_redaction' => 'Статус статьи - «редактируется»',
	'c_article_redaction_redacteur' => 'Статус статьи - «редактируется»',
	'c_article_redaction_redacteur_texte' => 'Чтобы отправить статью на утверждение администратором(ами) сайта, измените статус статьи с «готовится» на «утверждается».',
	'c_article_redaction_texte' => 'Чтобы статья появилась на сайте, вы должны изменить ее статус.
		В левой колонке изменить статус статьи с  «готовится» на «опубликована».',
	'c_articles_creer' => 'Как создать статью?',
	'c_articles_creer_texte' => 'Вы не можете создать статью на этой странице до тех пор, пока не создали хотя бы одну рубрику сайта. Чтобы создать рубрику наведите мышку на кнопку «Сайт» и выберете пункт меню «Рубрики».',
	'c_job' => 'Список задач',
	'c_job_texte' => 'На этой странице вы видите список задач, которые выполняет CMS SPIP. Некоторые задачи выполняются периодически, другие от случая к случаю - например отправка рассылки подписчикам.',
	'c_rubrique_publier' => 'Создайте статью',
	'c_rubrique_publier_texte' => 'Рубрика отображается на сайте только тогда, когда в ней есть хотя бы одна опубликованная статья. Если на вашем сайте в начале названия рубрики указан номер, то это её номер по порядку при выводе на страницах сайта. В таком случае рубрики без номера также показываться не будут. Вы можете использовать эту особенность, чтобы скрыть рубрику.

Итак, создайте статью. Кнопка находится на этой странице под описанием рубрики.',
	'c_rubriques_creer' => 'Создайте первую рубрику!',
	'c_rubriques_creer_texte' => 'Рубрики - это основа структуры сайта; вы можете создавать и хранить файлы в них. Попробуйте создать первую рубрику.',
	'c_sites_creer' => 'Как создать или импортировать сайт?',
	'c_sites_creer_texte' => 'Вы не можете создать или импортировать сайт с этой страницы, пока на вашем сайте нет разделов.
Вы можете создать раздел в меню «Сайт», затем «Разделы».',

	// E
	'explication_activer_compagnon' => '«Помощник» выводит специальные пояснения на некоторых страницах админки сайта, чтобы пользователю было легче освоится. Вы хотите включить «Помощника»?',
	'explication_reinitialiser_compagnon' => 'Подсказки, которые пользователь уже видел, не будут показываться в дальнейшем.
Показать подсказки заново?',

	// L
	'label_activer_compagnon' => 'Включить «Помощника»?',
	'label_reinitialiser_compagnon' => 'Показать заново подсказки «Помощника»?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'ОК',
	'ok_jai_compris' => 'Есть!',
	'ok_merci' => 'Спасибо',
	'ok_parfait' => 'Отлично!',

	// R
	'reinitialisation' => 'Показать заново подсказки',
	'reinitialisation_ok' => 'Готово!',
	'reinitialiser' => 'Сбросить',
	'reinitialiser_moi' => 'Да, только для меня',
	'reinitialiser_tous' => 'Да, для всех авторов',

	// T
	'titre_compagnon' => '«Помощник»',
	'titre_page_configurer_compagnon' => 'Настройки «Помощника»'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=ru
// ** ne pas modifier le fichier **

return [

	// C
	'c_accueil_bienvenue' => 'Добрый день @nom@ !',
	'c_accueil_configurer_site' => 'Настроить сайт',
	'c_accueil_configurer_site_texte' => 'Первое, что вы можете сделать - это изменить название вашего сайта.
Сейчас он называется «@nom@». Название  показывается в правом верхнем углу страницы. Нажав на имя сайта вы можете изменить его.',
	'c_accueil_publication' => 'Опубликовать!',
	'c_accueil_publication_texte' => 'Чтобы сделать новую страницу сайта вам необходимо создать новую статью. Также необходимо, чтобы у вас была минимум одна рубрика сайта. Если на сайте нет ни одной рубрики, вы можете создать её, нажав на пункт меню «Сайт -> Рубрики» в верхней панели управления.',
	'c_accueil_texte' => 'Вы только что вошли в систему управления вашим сайтом - CMS SPIP.',
	'c_accueil_texte_revenir' => '		На этой странице отображаются последние изменения, которые были выполненный на сайте. В дальнейшем вы можете вернуться на эту страницу, нажав на кнопку «Главная» в левом верхнем углу страницы.',
	'c_article_redaction' => 'Статус статьи - «редактируется»',
	'c_article_redaction_redacteur' => 'Статус статьи - «редактируется»',
	'c_article_redaction_redacteur_texte' => 'Чтобы отправить статью на утверждение администратором(ами) сайта, измените статус статьи с «готовится» на «утверждается».',
	'c_article_redaction_texte' => 'Чтобы статья появилась на сайте, вы должны изменить ее статус.
		В левой колонке изменить статус статьи с  «готовится» на «опубликована».',
	'c_articles_creer' => 'Как создать статью?',
	'c_articles_creer_texte' => 'Вы не можете создать статью на этой странице до тех пор, пока не создали хотя бы одну рубрику сайта. Чтобы создать рубрику наведите мышку на кнопку «Сайт» и выберете пункт меню «Рубрики».',
	'c_job' => 'Список задач',
	'c_job_texte' => 'На этой странице вы видите список задач, которые выполняет CMS SPIP. Некоторые задачи выполняются периодически, другие от случая к случаю - например отправка рассылки подписчикам.',
	'c_rubrique_publier' => 'Создайте статью',
	'c_rubrique_publier_texte' => 'Рубрика отображается на сайте только тогда, когда в ней есть хотя бы одна опубликованная статья. Если на вашем сайте в начале названия рубрики указан номер, то это её номер по порядку при выводе на страницах сайта. В таком случае рубрики без номера также показываться не будут. Вы можете использовать эту особенность, чтобы скрыть рубрику.

Итак, создайте статью. Кнопка находится на этой странице под описанием рубрики.',
	'c_rubriques_creer' => 'Создайте первую рубрику!',
	'c_rubriques_creer_texte' => 'Рубрики - это основа структуры сайта; вы можете создавать и хранить файлы в них. Попробуйте создать первую рубрику.',
	'c_sites_creer' => 'Как создать или импортировать сайт?',
	'c_sites_creer_texte' => 'Вы не можете создать или импортировать сайт с этой страницы, пока на вашем сайте нет разделов.
Вы можете создать раздел в меню «Сайт», затем «Разделы».',

	// E
	'explication_activer_compagnon' => '«Помощник» выводит специальные пояснения на некоторых страницах админки сайта, чтобы пользователю было легче освоится. Вы хотите включить «Помощника»?',
	'explication_reinitialiser_compagnon' => 'Подсказки, которые пользователь уже видел, не будут показываться в дальнейшем.
Показать подсказки заново?',

	// L
	'label_activer_compagnon' => 'Включить «Помощника»?',
	'label_reinitialiser_compagnon' => 'Показать заново подсказки «Помощника»?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'ОК',
	'ok_jai_compris' => 'Есть!',
	'ok_merci' => 'Спасибо',
	'ok_parfait' => 'Отлично!',

	// R
	'reinitialisation' => 'Показать заново подсказки',
	'reinitialisation_ok' => 'Готово!',
	'reinitialiser' => 'Сбросить',
	'reinitialiser_moi' => 'Да, только для меня',
	'reinitialiser_tous' => 'Да, для всех авторов',

	// T
	'titre_compagnon' => '«Помощник»',
	'titre_page_configurer_compagnon' => 'Настройки «Помощника»',
];
